pub struct UpdateOneofLimitedEncodeAccountInner<'a> {
pub pubkey: &'a Pubkey,
pub lamports: u64,
pub owner: &'a Pubkey,
pub executable: bool,
pub rent_epoch: u64,
pub data: Cow<'a, [u8]>,
pub write_version: u64,
pub txn_signature: Option<&'a [u8]>,
}Fields
pubkey: &'a Pubkeylamports: u64owner: &'a Pubkeyexecutable: boolrent_epoch: u64data: Cow<'a, [u8]>write_version: u64txn_signature: Option<&'a [u8]>Trait Implementations
Sourceimpl<'a> Debug for UpdateOneofLimitedEncodeAccountInner<'a>
impl<'a> Debug for UpdateOneofLimitedEncodeAccountInner<'a>
Sourceimpl Message for UpdateOneofLimitedEncodeAccountInner<'_>
impl Message for UpdateOneofLimitedEncodeAccountInner<'_>
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Auto Trait Implementations
impl<'a> Freeze for UpdateOneofLimitedEncodeAccountInner<'a>
impl<'a> RefUnwindSafe for UpdateOneofLimitedEncodeAccountInner<'a>
impl<'a> Send for UpdateOneofLimitedEncodeAccountInner<'a>
impl<'a> Sync for UpdateOneofLimitedEncodeAccountInner<'a>
impl<'a> Unpin for UpdateOneofLimitedEncodeAccountInner<'a>
impl<'a> UnwindSafe for UpdateOneofLimitedEncodeAccountInner<'a>